@@ -147,6 +147,7 @@ typedef enum
 	FreeRDP_GatewayHttpUseWebsockets = 2000,
 	FreeRDP_GatewayHttpExtAuthSspiNtlm = 2001,
 	FreeRDP_GatewayArmTransport = 2004,
+	FreeRDP_GatewayIgnoreRedirectionPolicy = 2012,
 	FreeRDP_RemoteApplicationMode = 2112,
 	FreeRDP_DisableRemoteAppCapsCheck = 2121,
 	FreeRDP_RemoteAppLanguageBarSupported = 2124,
@@ -210,7 +211,9 @@ typedef enum
 	FreeRDP_RedirectParallelPorts = 4673,
 	FreeRDP_PreferIPv6OverIPv4 = 4674,
 	FreeRDP_RedirectClipboard = 4800,
+	FreeRDP_SynchronousStaticChannels = 4931,
 	FreeRDP_SupportDynamicChannels = 5059,
+	FreeRDP_SynchronousDynamicChannels = 5060,
 	FreeRDP_SupportEchoChannel = 5184,
 	FreeRDP_SupportDisplayControl = 5185,
 	FreeRDP_SupportGeometryTracking = 5186,
