@@ -467,7 +467,8 @@ struct rdp_settings
 	SETTINGS_DEPRECATED(ALIGN64 char* GatewayAvdDiagnosticserviceurl); /* 2009 */
 	SETTINGS_DEPRECATED(ALIGN64 char* GatewayAvdHubdiscoverygeourl);   /* 2010 */
 	SETTINGS_DEPRECATED(ALIGN64 char* GatewayAvdActivityhint);         /* 2011 */
-	UINT64 padding2015[2015 - 2012];                                   /* 2012 */
+	SETTINGS_DEPRECATED(ALIGN64 BOOL GatewayIgnoreRedirectionPolicy);  /* 2012 */
+	UINT64 padding2015[2015 - 2013];                                   /* 2013 */
 
 	/* Proxy */
 	SETTINGS_DEPRECATED(ALIGN64 UINT32 ProxyType);    /* 2015 */
@@ -760,7 +761,8 @@ struct rdp_settings
 	SETTINGS_DEPRECATED(ALIGN64 UINT32 StaticChannelCount);       /* 4928 */
 	SETTINGS_DEPRECATED(ALIGN64 UINT32 StaticChannelArraySize);   /* 4929 */
 	SETTINGS_DEPRECATED(ALIGN64 ADDIN_ARGV** StaticChannelArray); /* 4930 */
-	UINT64 padding5056[5056 - 4931];                              /* 4931 */
+	SETTINGS_DEPRECATED(ALIGN64 BOOL SynchronousStaticChannels);  /* 4931 */
+	UINT64 padding5056[5056 - 4932];                              /* 4932 */
 
 	/**
 	 * Dynamic Virtual Channels
@@ -770,7 +772,8 @@ struct rdp_settings
 	SETTINGS_DEPRECATED(ALIGN64 UINT32 DynamicChannelArraySize);   /* 5057 */
 	SETTINGS_DEPRECATED(ALIGN64 ADDIN_ARGV** DynamicChannelArray); /* 5058 */
 	SETTINGS_DEPRECATED(ALIGN64 BOOL SupportDynamicChannels);      /* 5059 */
-	UINT64 padding5184[5184 - 5060];                               /* 5060 */
+	SETTINGS_DEPRECATED(ALIGN64 BOOL SynchronousDynamicChannels);  /* 5060 */
+	UINT64 padding5184[5184 - 5061];                               /* 5061 */
 
 	SETTINGS_DEPRECATED(ALIGN64 BOOL SupportEchoChannel);        /* 5184 */
 	SETTINGS_DEPRECATED(ALIGN64 BOOL SupportDisplayControl);     /* 5185 */
