@@ -21,12 +21,15 @@
 #define FREERDP_VERSION_H
 
 #define FREERDP_VERSION_MAJOR 3
-#define FREERDP_VERSION_MINOR 1
+#define FREERDP_VERSION_MINOR 4
 #define FREERDP_VERSION_REVISION 0
-#define FREERDP_VERSION_SUFFIX "1"
+#define FREERDP_VERSION_SUFFIX ""
 #define FREERDP_API_VERSION "3"
-#define FREERDP_VERSION "3.1.0"
-#define FREERDP_VERSION_FULL "3.1.0-1"
-#define FREERDP_GIT_REVISION "2-3.1.0-1"
+#define FREERDP_VERSION "3.4.0"
+#define FREERDP_VERSION_FULL "3.4.0"
+#define FREERDP_GIT_REVISION "n/a"
+#define FREERDP_USER_AGENT "FreeRDP/3.4.0"
+#define FREERDP_VENDOR "FreeRDP"
+#define FREERDP_PRODUCT "FreeRDP"
 
 #endif /* FREERDP_VERSION_H */
